-- Convert schema '/2home/ss5/local/projects/Tapper/src/Tapper-Schema/upgrades/Tapper-Schema-ReportsDB-2.010009-MySQL.sql' to '/2home/ss5/local/projects/Tapper/src/Tapper-Schema/upgrades/Tapper-Schema-ReportsDB-2.010010-MySQL.sql':

-- No differences found

