
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    require Test::More;
    Test::More::plan(skip_all => 'these tests are for testing by the author');
  }
}

use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::NoTabs 0.15

use Test::More 0.88;
use Test::NoTabs;

my @files = (
    'lib/Tapper/RawSQL/ReportsDB/reports.pm',
    'lib/Tapper/RawSQL/TestrunDB/reports.pm',
    'lib/Tapper/RawSQL/TestrunDB/testruns.pm',
    'lib/Tapper/Schema.pm',
    'lib/Tapper/Schema/ReportsDB.pm',
    'lib/Tapper/Schema/TestTools.pm',
    'lib/Tapper/Schema/TestrunDB.pm',
    'lib/Tapper/Schema/TestrunDB/Result/BenchAdditionalRelations.pm',
    'lib/Tapper/Schema/TestrunDB/Result/BenchAdditionalTypeRelations.pm',
    'lib/Tapper/Schema/TestrunDB/Result/BenchAdditionalTypes.pm',
    'lib/Tapper/Schema/TestrunDB/Result/BenchAdditionalValues.pm',
    'lib/Tapper/Schema/TestrunDB/Result/BenchBackupAdditionalRelations.pm',
    'lib/Tapper/Schema/TestrunDB/Result/BenchBackupValues.pm',
    'lib/Tapper/Schema/TestrunDB/Result/BenchSubsumeTypes.pm',
    'lib/Tapper/Schema/TestrunDB/Result/BenchUnits.pm',
    'lib/Tapper/Schema/TestrunDB/Result/BenchValues.pm',
    'lib/Tapper/Schema/TestrunDB/Result/Benchs.pm',
    'lib/Tapper/Schema/TestrunDB/Result/ChartAxisTypes.pm',
    'lib/Tapper/Schema/TestrunDB/Result/ChartLineAdditionals.pm',
    'lib/Tapper/Schema/TestrunDB/Result/ChartLineAxisColumns.pm',
    'lib/Tapper/Schema/TestrunDB/Result/ChartLineAxisElements.pm',
    'lib/Tapper/Schema/TestrunDB/Result/ChartLineAxisSeparators.pm',
    'lib/Tapper/Schema/TestrunDB/Result/ChartLineRestrictionValues.pm',
    'lib/Tapper/Schema/TestrunDB/Result/ChartLineRestrictions.pm',
    'lib/Tapper/Schema/TestrunDB/Result/ChartLines.pm',
    'lib/Tapper/Schema/TestrunDB/Result/ChartMarkings.pm',
    'lib/Tapper/Schema/TestrunDB/Result/ChartTagRelations.pm',
    'lib/Tapper/Schema/TestrunDB/Result/ChartTags.pm',
    'lib/Tapper/Schema/TestrunDB/Result/ChartTinyUrlLines.pm',
    'lib/Tapper/Schema/TestrunDB/Result/ChartTinyUrlRelations.pm',
    'lib/Tapper/Schema/TestrunDB/Result/ChartTinyUrls.pm',
    'lib/Tapper/Schema/TestrunDB/Result/ChartTypes.pm',
    'lib/Tapper/Schema/TestrunDB/Result/ChartVersions.pm',
    'lib/Tapper/Schema/TestrunDB/Result/Charts.pm',
    'lib/Tapper/Schema/TestrunDB/Result/Contact.pm',
    'lib/Tapper/Schema/TestrunDB/Result/DeniedHost.pm',
    'lib/Tapper/Schema/TestrunDB/Result/Host.pm',
    'lib/Tapper/Schema/TestrunDB/Result/HostFeature.pm',
    'lib/Tapper/Schema/TestrunDB/Result/Message.pm',
    'lib/Tapper/Schema/TestrunDB/Result/Notification.pm',
    'lib/Tapper/Schema/TestrunDB/Result/NotificationEvent.pm',
    'lib/Tapper/Schema/TestrunDB/Result/Owner.pm',
    'lib/Tapper/Schema/TestrunDB/Result/PrePrecondition.pm',
    'lib/Tapper/Schema/TestrunDB/Result/Precondition.pm',
    'lib/Tapper/Schema/TestrunDB/Result/Preconditiontype.pm',
    'lib/Tapper/Schema/TestrunDB/Result/Queue.pm',
    'lib/Tapper/Schema/TestrunDB/Result/QueueHost.pm',
    'lib/Tapper/Schema/TestrunDB/Result/Report.pm',
    'lib/Tapper/Schema/TestrunDB/Result/ReportComment.pm',
    'lib/Tapper/Schema/TestrunDB/Result/ReportFile.pm',
    'lib/Tapper/Schema/TestrunDB/Result/ReportSection.pm',
    'lib/Tapper/Schema/TestrunDB/Result/ReportTopic.pm',
    'lib/Tapper/Schema/TestrunDB/Result/ReportgroupArbitrary.pm',
    'lib/Tapper/Schema/TestrunDB/Result/ReportgroupTestrun.pm',
    'lib/Tapper/Schema/TestrunDB/Result/ReportgroupTestrunStats.pm',
    'lib/Tapper/Schema/TestrunDB/Result/Scenario.pm',
    'lib/Tapper/Schema/TestrunDB/Result/ScenarioElement.pm',
    'lib/Tapper/Schema/TestrunDB/Result/State.pm',
    'lib/Tapper/Schema/TestrunDB/Result/Suite.pm',
    'lib/Tapper/Schema/TestrunDB/Result/Tap.pm',
    'lib/Tapper/Schema/TestrunDB/Result/TestplanInstance.pm',
    'lib/Tapper/Schema/TestrunDB/Result/Testrun.pm',
    'lib/Tapper/Schema/TestrunDB/Result/TestrunPrecondition.pm',
    'lib/Tapper/Schema/TestrunDB/Result/TestrunRequestedFeature.pm',
    'lib/Tapper/Schema/TestrunDB/Result/TestrunRequestedHost.pm',
    'lib/Tapper/Schema/TestrunDB/Result/TestrunScheduling.pm',
    'lib/Tapper/Schema/TestrunDB/Result/Topic.pm',
    'lib/Tapper/Schema/TestrunDB/Result/View010TestrunOverviewReports.pm',
    'lib/Tapper/Schema/TestrunDB/Result/View020TestrunOverview.pm',
    'lib/Tapper/Schema/TestrunDB/ResultSet/Host.pm',
    'lib/Tapper/Schema/TestrunDB/ResultSet/Precondition.pm',
    'lib/Tapper/Schema/TestrunDB/ResultSet/Queue.pm',
    'lib/Tapper/Schema/TestrunDB/ResultSet/ReportgroupTestrun.pm',
    'lib/Tapper/Schema/TestrunDB/ResultSet/Testrun.pm',
    'lib/Tapper/Schema/TestrunDB/ResultSet/TestrunScheduling.pm',
    't/00-load.t',
    't/author-eol.t',
    't/author-no-tabs.t',
    't/author-pod-syntax.t',
    't/fixtures/README',
    't/fixtures/hardwaredb/systems.yml',
    't/fixtures/reportsdb/report.yml',
    't/fixtures/reportsdb/reportgroups.yml',
    't/fixtures/reportsdb/reportgroupviews.yml',
    't/fixtures/reportsdb/reportsection.yml',
    't/fixtures/testrundb/denyhost.yaml',
    't/fixtures/testrundb/owner.yml',
    't/fixtures/testrundb/pool_testrun.yml',
    't/fixtures/testrundb/precondition_structures.yml',
    't/fixtures/testrundb/preconditions_with_yaml.yml',
    't/fixtures/testrundb/report.yml',
    't/fixtures/testrundb/reportgroups.yml',
    't/fixtures/testrundb/reportgroupviews.yml',
    't/fixtures/testrundb/reportsection.yml',
    't/fixtures/testrundb/simple_testrun.yml',
    't/fixtures/testrundb/testrun.yml',
    't/fixtures/testrundb/testrun_with_preconditions.yml',
    't/fixtures/testrundb/testrun_with_preconditions2.yml',
    't/fixtures/testrundb/testruns_with_states.yml',
    't/fixtures/testrundb/topic.yml',
    't/fixtures/testsdb/version.yml',
    't/tapper-schema-testrun-pool.t',
    't/tapper-schema-testrun-precondition.t',
    't/tapper-schema-testrun.t',
    't/tapper_schema_reportsdb.t',
    't/tapper_schema_reportsdb_reportgroups.t',
    't/tapper_schema_reportsdb_reportgroupviews.t',
    't/tapper_schema_testrundb.t'
);

notabs_ok($_) foreach @files;
done_testing;
