-- Convert schema 'lib/auto/Tapper/Schema/Tapper-Schema-TestrunDB-4.001002-SQLite.sql' to 'lib/auto/Tapper/Schema/Tapper-Schema-TestrunDB-4.001003-SQLite.sql':;

BEGIN;

CREATE UNIQUE INDEX constraint_name02 ON host (name);


COMMIT;

