-- Convert schema '/home/mhentsc3/perl510/lib/site_perl/5.10.0/auto/Tapper/Schema/Tapper-Schema-TestrunDB-3.000001-SQLite.sql' to '/home/mhentsc3/perl510/lib/site_perl/5.10.0/auto/Tapper/Schema/Tapper-Schema-TestrunDB-3.000001-SQLite.sql':;

-- No differences found;

