package Tapper::Schema;
# git description: v5.0.7-1-gfc8605b

our $AUTHORITY = 'cpan:TAPPER';
# ABSTRACT: Tapper - Database schemas for Tapper
$Tapper::Schema::VERSION = '5.0.8';
use warnings;
use strict;

1; # End of Tapper::Schema

__END__

=pod

=encoding UTF-8

=head1 NAME

Tapper::Schema - Tapper - Database schemas for Tapper

=head1 AUTHORS

=over 4

=item *

AMD OSRC Tapper Team <tapper@amd64.org>

=item *

Tapper Team <tapper-ops@amazon.com>

=back

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..

This is free software, licensed under:

  The (two-clause) FreeBSD License

=cut
